MethodChannelFlutterAutoOrientation class

Default implementation using MethodChannel to interact with the native platform. 使用 MethodChannel 与原生交互的默认实现。

Inheritance

Properties

hashCode → int
The hash code for this object.
no setterinherited
methodChannel → MethodChannel
The communication channel with the native platform. The channel name must be consistent with the Android/iOS plugin. 与原生通信的通道,通道名需与 Android/iOS 插件保持一致。
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setOrientation(String method, {bool forceSensor = false}) → Future<void>
Sets the screen orientation. This method must be implemented by all concrete platforms. 设置屏幕方向。所有具体平台必须实现此方法。
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited